==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Sendikasyon te pa mache : "backend"  te rele konsa se pa posib fé lekti osnon se li pa pwopoze okenn atik kounye-a.',
	'avis_echec_syndication_02' => 'Sendikasyon te pa mache : gen enposib aksede "backend" sit-la.',
	'avis_site_introuvable' => 'Sit la, gen pa rann kont ali',
	'avis_site_syndique_probleme' => 'Atansyon : sendikasyon pou sit sa-a gen yon pwoblèm ; sistèm pa mache kounyen-a. Gad si ladrès fichye sendikasyon sit-la se korèk (<b>@url_syndic@</b>), aprèsa ann esey yon lòt rekipérasyon enfòmasyon sa-yo. ', # MODIF
	'avis_sites_probleme_syndication' => 'Sit yo se sit sak gen yon pwoblèm sendikasyon',
	'avis_sites_syndiques_probleme' => 'Sit yon se sit sak té bay yon pwoblèm',

	// B
	'bouton_radio_modere_posteriori' => 'Modewe dèyè', # MODIF
	'bouton_radio_modere_priori' => 'modewe avan', # MODIF
	'bouton_radio_non_syndication' => 'Okenn sendikasyon',
	'bouton_radio_syndication' => 'Sendikasyon :',

	// E
	'entree_adresse_fichier_syndication' => 'Ladrès fichye pou la sendikasyon :',
	'entree_adresse_site' => '<b>Ladrès sit la</b> [Nésesè]',
	'entree_description_site' => 'Dekrisyon sit-la',

	// F
	'form_prop_nom_site' => 'Kouman sit la i rele',

	// I
	'icone_modifier_site' => 'Chanje sit la',
	'icone_referencer_nouveau_site' => 'Referans yon nouvo sit',
	'icone_voir_sites_references' => 'Gad sit referanse yo',
	'info_1_site' => '1 sitwèb',
	'info_a_valider' => '[pou konfime]',
	'info_bloquer' => 'bloké',
	'info_bloquer_lien' => 'blok lyen nan',
	'info_derniere_syndication' => 'Dènye sendikasyon sit-la te fin  fè an jou',
	'info_liens_syndiques_1' => 'lyen sendike sa-yo',
	'info_liens_syndiques_2' => 'ki tan pou yon komandè konfime yo.',
	'info_nom_site_2' => '<b>Kouman sit la li rele</b> [Nesesé]',
	'info_panne_site_syndique' => 'Sit sendike a se pa mache',
	'info_probleme_grave' => 'pwoblèm ek',
	'info_question_proposer_site' => 'Kimoun kapab pwopoze kèk sit referansé ?',
	'info_retablir_lien' => 'Romèt lyen-nan',
	'info_site_attente' => 'Sit web ki tann yon komandè konfime ali',
	'info_site_propose' => 'Sit pwopoze an jou :',
	'info_site_reference' => 'Sit referanse an liy',
	'info_site_refuse' => 'Sit we ki te fin refize',
	'info_site_syndique' => 'Sit-la se sendike...', # MODIF
	'info_site_valider' => 'Sit sa-yo se sit yo ki pou konfime',
	'info_sites_referencer' => 'Referanse yon sit',
	'info_sites_refuses' => 'Sit sa-yo ki te refize',
	'info_statut_site_1' => 'Sit-la se :',
	'info_statut_site_2' => 'Pibliye',
	'info_statut_site_3' => 'Pwopoze pou parèt ',
	'info_statut_site_4' => 'Nan bwat poubèl', # MODIF
	'info_syndication' => 'sendikasyon :',
	'info_syndication_articles' => 'atik (yo)',
	'item_bloquer_liens_syndiques' => 'Bloke lyen lasendikasyon sa-yo ki pou konfime',
	'item_gerer_annuaire_site_web' => 'Okipe yon laniye sit web yo',
	'item_non_bloquer_liens_syndiques' => 'Blok pa lyen ki soti senkikasyon an',
	'item_non_gerer_annuaire_site_web' => 'Rotir lanyie sit web',
	'item_non_utiliser_syndication' => 'Itilize pa sendikasyon otomatik',
	'item_utiliser_syndication' => 'Itilize sendikasyon otomatik',

	// L
	'lien_mise_a_jour_syndication' => 'arnouvèl kounye-a',
	'lien_nouvelle_recuperation' => 'esey yon lòt rékipérasyon tout done sa-yo',

	// S
	'syndic_choix_moderation' => 'Kisa SPIP ka fè ak pwochen lyanaj ki soti sit-la ?',
	'syndic_choix_oublier' => 'Kisa SPIP ka fè ak lyanaj ki pa pwézan nan fichyé sendikasyon la ?',
	'syndic_lien_obsolete' => 'lianaj se two vyé',
	'syndic_option_miroir' => 'rèt sa-yo otomatikman',
	'syndic_option_oubli' => 'efase yo (apwè @mois@ mwa)',
	'syndic_options' => 'Tout opsyon pou sendikasyon :',

	// T
	'texte_liens_sites_syndiques' => 'Tout lyen ki sòti tout sit sendike, genyen
posib blok azot dabò ; réglaj isit
   anba se réglaj otomatik pou tout sit apré kreasyon sendikasyon azot
   posib déblok azot aprè, ou debloke selman lyen pa lyen, osnon chwazi bloke  sit pa sit, tput lyen ki sòit laveni sou sit sa-yo. ', # MODIF
	'texte_messages_publics' => 'Mesaj piblik yo ki nan atik-la :',
	'texte_non_fonction_referencement' => 'W ka vle pa itilize fonksyon otomatik la, men endike w mèm tout éléman yo ki pale sit-la...', # MODIF
	'texte_referencement_automatique' => '<b>Référansman otomatik pou yon sitweb</b><br />W kapab referanse fasilman yon sitweb si w bay ladrès URL osnon bay ladrès fichye backend ali. SPIP ke pran otomatikman tout enfòmasyon posib pou sit-la (kouman li rele, dekrisyon...).', # MODIF
	'texte_syndication' => 'Kank sitweb-la li pèmè bagay-sa-a, se posib pran otomatikman lis tout nouvèlté ali. 
Fòk w aktive sendikasyon an. 
  <blockquote><i>Tansyon kèk zébèrjè, zot ka dézaktiv fonksyonalité-a ; 
  akoz bagay-la, inposib pran sendikasyon-an depi sit aou
.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Atik sendike ki rale yo sit la',
	'titre_dernier_article_syndique' => 'Tout denye atik sendike',
	'titre_page_sites_tous' => 'Tout sit referanse yo',
	'titre_referencement_sites' => 'Referansman pou tout sit yo ak sendikasyon ',
	'titre_site_numero' => 'SIT NIMEWO :',
	'titre_sites_proposes' => 'Tout sit pwopoze ',
	'titre_sites_references_rubrique' => 'Tout sit referanse nan pati sa a nan sit la',
	'titre_sites_syndiques' => 'Tout sit sendike yo',
	'titre_sites_tous' => 'Tout sit referanse andan sit la',
	'titre_syndication' => 'Sendikasyon pou tout sit yo'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// A
	'avis_echec_syndication_01' => 'Sendikasyon te pa mache : "backend"  te rele konsa se pa posib fé lekti osnon se li pa pwopoze okenn atik kounye-a.',
	'avis_echec_syndication_02' => 'Sendikasyon te pa mache : gen enposib aksede "backend" sit-la.',
	'avis_site_introuvable' => 'Sit la, gen pa rann kont ali',
	'avis_site_syndique_probleme' => 'Atansyon : sendikasyon pou sit sa-a gen yon pwoblèm ; sistèm pa mache kounyen-a. Gad si ladrès fichye sendikasyon sit-la se korèk (<b>@url_syndic@</b>), aprèsa ann esey yon lòt rekipérasyon enfòmasyon sa-yo. ', # MODIF
	'avis_sites_probleme_syndication' => 'Sit yo se sit sak gen yon pwoblèm sendikasyon',
	'avis_sites_syndiques_probleme' => 'Sit yon se sit sak té bay yon pwoblèm',

	// B
	'bouton_radio_modere_posteriori' => 'Modewe dèyè', # MODIF
	'bouton_radio_modere_priori' => 'modewe avan', # MODIF
	'bouton_radio_non_syndication' => 'Okenn sendikasyon',
	'bouton_radio_syndication' => 'Sendikasyon :',

	// E
	'entree_adresse_fichier_syndication' => 'Ladrès fichye pou la sendikasyon :',
	'entree_adresse_site' => '<b>Ladrès sit la</b> [Nésesè]',
	'entree_description_site' => 'Dekrisyon sit-la',

	// F
	'form_prop_nom_site' => 'Kouman sit la i rele',

	// I
	'icone_modifier_site' => 'Chanje sit la',
	'icone_referencer_nouveau_site' => 'Referans yon nouvo sit',
	'icone_voir_sites_references' => 'Gad sit referanse yo',
	'info_1_site' => '1 sitwèb',
	'info_a_valider' => '[pou konfime]',
	'info_bloquer' => 'bloké',
	'info_bloquer_lien' => 'blok lyen nan',
	'info_derniere_syndication' => 'Dènye sendikasyon sit-la te fin  fè an jou',
	'info_liens_syndiques_1' => 'lyen sendike sa-yo',
	'info_liens_syndiques_2' => 'ki tan pou yon komandè konfime yo.',
	'info_nom_site_2' => '<b>Kouman sit la li rele</b> [Nesesé]',
	'info_panne_site_syndique' => 'Sit sendike a se pa mache',
	'info_probleme_grave' => 'pwoblèm ek',
	'info_question_proposer_site' => 'Kimoun kapab pwopoze kèk sit referansé ?',
	'info_retablir_lien' => 'Romèt lyen-nan',
	'info_site_attente' => 'Sit web ki tann yon komandè konfime ali',
	'info_site_propose' => 'Sit pwopoze an jou :',
	'info_site_reference' => 'Sit referanse an liy',
	'info_site_refuse' => 'Sit we ki te fin refize',
	'info_site_syndique' => 'Sit-la se sendike...', # MODIF
	'info_site_valider' => 'Sit sa-yo se sit yo ki pou konfime',
	'info_sites_referencer' => 'Referanse yon sit',
	'info_sites_refuses' => 'Sit sa-yo ki te refize',
	'info_statut_site_1' => 'Sit-la se :',
	'info_statut_site_2' => 'Pibliye',
	'info_statut_site_3' => 'Pwopoze pou parèt ',
	'info_statut_site_4' => 'Nan bwat poubèl', # MODIF
	'info_syndication' => 'sendikasyon :',
	'info_syndication_articles' => 'atik (yo)',
	'item_bloquer_liens_syndiques' => 'Bloke lyen lasendikasyon sa-yo ki pou konfime',
	'item_gerer_annuaire_site_web' => 'Okipe yon laniye sit web yo',
	'item_non_bloquer_liens_syndiques' => 'Blok pa lyen ki soti senkikasyon an',
	'item_non_gerer_annuaire_site_web' => 'Rotir lanyie sit web',
	'item_non_utiliser_syndication' => 'Itilize pa sendikasyon otomatik',
	'item_utiliser_syndication' => 'Itilize sendikasyon otomatik',

	// L
	'lien_mise_a_jour_syndication' => 'arnouvèl kounye-a',
	'lien_nouvelle_recuperation' => 'esey yon lòt rékipérasyon tout done sa-yo',

	// S
	'syndic_choix_moderation' => 'Kisa SPIP ka fè ak pwochen lyanaj ki soti sit-la ?',
	'syndic_choix_oublier' => 'Kisa SPIP ka fè ak lyanaj ki pa pwézan nan fichyé sendikasyon la ?',
	'syndic_lien_obsolete' => 'lianaj se two vyé',
	'syndic_option_miroir' => 'rèt sa-yo otomatikman',
	'syndic_option_oubli' => 'efase yo (apwè @mois@ mwa)',
	'syndic_options' => 'Tout opsyon pou sendikasyon :',

	// T
	'texte_liens_sites_syndiques' => 'Tout lyen ki sòti tout sit sendike, genyen
posib blok azot dabò ; réglaj isit
   anba se réglaj otomatik pou tout sit apré kreasyon sendikasyon azot
   posib déblok azot aprè, ou debloke selman lyen pa lyen, osnon chwazi bloke  sit pa sit, tput lyen ki sòit laveni sou sit sa-yo. ', # MODIF
	'texte_messages_publics' => 'Mesaj piblik yo ki nan atik-la :',
	'texte_non_fonction_referencement' => 'W ka vle pa itilize fonksyon otomatik la, men endike w mèm tout éléman yo ki pale sit-la...', # MODIF
	'texte_referencement_automatique' => '<b>Référansman otomatik pou yon sitweb</b><br />W kapab referanse fasilman yon sitweb si w bay ladrès URL osnon bay ladrès fichye backend ali. SPIP ke pran otomatikman tout enfòmasyon posib pou sit-la (kouman li rele, dekrisyon...).', # MODIF
	'texte_syndication' => 'Kank sitweb-la li pèmè bagay-sa-a, se posib pran otomatikman lis tout nouvèlté ali. 
Fòk w aktive sendikasyon an. 
  <blockquote><i>Tansyon kèk zébèrjè, zot ka dézaktiv fonksyonalité-a ; 
  akoz bagay-la, inposib pran sendikasyon-an depi sit aou
.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Atik sendike ki rale yo sit la',
	'titre_dernier_article_syndique' => 'Tout denye atik sendike',
	'titre_page_sites_tous' => 'Tout sit referanse yo',
	'titre_referencement_sites' => 'Referansman pou tout sit yo ak sendikasyon ',
	'titre_site_numero' => 'SIT NIMEWO :',
	'titre_sites_proposes' => 'Tout sit pwopoze ',
	'titre_sites_references_rubrique' => 'Tout sit referanse nan pati sa a nan sit la',
	'titre_sites_syndiques' => 'Tout sit sendike yo',
	'titre_sites_tous' => 'Tout sit referanse andan sit la',
	'titre_syndication' => 'Sendikasyon pou tout sit yo',
];
